# LaTeX2HTML 2024 (Released January 1, 2024)
# Associate labels original text with physical files.


$key = q/SubSec:badpara/;
$external_labels{$key} = "$URL/" . q|node18.html|; 
$noresave{$key} = "$nosave";

$key = q/pw2casino_info/;
$external_labels{$key} = "$URL/" . q|node12.html|; 
$noresave{$key} = "$nosave";

1;


# LaTeX2HTML 2024 (Released January 1, 2024)
# labels from external_latex_labels array.


$key = q/SubSec:badpara/;
$external_latex_labels{$key} = q|4.4 Parallelization issues|; 
$noresave{$key} = "$nosave";

$key = q/pw2casino_info/;
$external_latex_labels{$key} = q|3.5 Direct interface with <TT>CASINO</TT>|; 
$noresave{$key} = "$nosave";

1;

